@@ -3,6 +3,9 @@ from .app import App
 app = App()
 
 __all__ = [
+    'App',
+    'dataset',
+    'dataframe',
     'box',
     'fns',
     'add_srcipt',
@@ -39,6 +42,7 @@ button = app.button
 box = app.box
 add_srcipt = app.add_srcipt
 dataTable = app.dataTable
+dataframe = app.dataframe
 input = app.input
 echart = app.echart
 inputNumber = app.inputNumber
@@ -54,7 +58,8 @@ icon = app.icon
 row=app.row
 file=app.file
 
-# v = FnContext()
+dataset = app.dataset
+
 
 config2file = app.config2file
 to_html = app.to_html
