@@ -1,9 +1,10 @@
 from typing import Union,Dict,List
 from pyvisflow.core.components.components import Component
-from pyvisflow.core.props import TypePropInfo,StrTypePropInfo,SubscriptableTypePropInfo, NumberTypePropInfo, BoolTypePropInfo
+from pyvisflow.core.props import StrTypePropInfo, NumberTypePropInfo, BoolTypePropInfo
 from pyvisflow.models.TComponent import TComponentType
 from pyvisflow.core.props import *
 
+TypePropInfo=Union[StrTypePropInfo,NumberTypePropInfo,BoolTypePropInfo]
 
 class _DataTable(Component):
     '''
@@ -40,28 +41,6 @@ class _DataTable(Component):
         '''
         self.set_prop('currentPage', value)
 
-    @property
-    def show_columns(self):
-        '''
-        可选值：nan \n
-        表格显示的列。当你希望页面表格只输出数据一部分列的时候可以设置此属性
-        '''
-
-        
-        p = self.get_prop('showColumns')
-        return SubscriptableTypePropInfo[int,StrTypePropInfo](p)
-
-        
-
-
-    @show_columns.setter
-    def show_columns(self, value: Union[SubscriptableTypePropInfo[int,StrTypePropInfo],List[str]]):
-        '''
-        可选值：nan \n
-        表格显示的列。当你希望页面表格只输出数据一部分列的时候可以设置此属性
-        '''
-        self.set_prop('showColumns', value)
-
     @property
     def page_size(self):
         '''
