@@ -3,8 +3,10 @@ from __future__ import annotations
 from typing import Any, Callable, Dict, Iterable, List, TYPE_CHECKING, Optional, Union
 
 import pandas as pd
+from pandas.io.formats.style import Styler as pdStyler
 from pyvisflow.core.components.components import Component
 from pyvisflow.core.components.dataTable import DataTable
+from pyvisflow.core.components.dataframe import Dataframe
 from pyvisflow.core.components.echart import EChart
 from pyvisflow.core.components.icon import Icon
 from pyvisflow.core.components.input import Input
@@ -15,26 +17,23 @@ from pyvisflow.core.components.text import Text
 from pyvisflow.core.components.file import File
 from pyvisflow.core.components.image import Image
 from pyvisflow.core.components.button import Button
+from pyvisflow.core.dataset.props import DatasetSeriesArrayPropInfo, DatasetSeriesPropInfo, ReactiveDatasetPropInfo
 
 from pyvisflow.core.layout import MarkdownLayout
 from pyvisflow.core.props import BoolTypePropInfo
 
-import base64
 from io import BytesIO
 
 from pyvisflow.models.TComponent import TComponentType
 from pyvisflow.utils.data_gen import data2html_img_src
 
 if TYPE_CHECKING:
-    from pyvisflow.core.props import TypePropInfo
     from pyvisflow.core.components.file import FileData
-
+    from pyvisflow.core.props import TTypePropInfo
 
 class Container(Component):
-    # appender_stack: List[Callable[[Component]
     def __init__(self, tag: str, type=TComponentType.builtIn) -> None:
         super().__init__(tag, type)
-        # self._appender_stack = appender_stack
 
     def add_child(self, cp: Component):
         self._children.append(cp)
@@ -52,11 +51,13 @@ class BoxContainer(Container):
         self._spec = sepc
         self._on_before_data_fn = lambda data: data
         self._on_before_add_child_fn = BoxContainer.__default_on_before_add_child_fn
+        self._teleportTarget=''
 
     @staticmethod
     def __default_on_before_add_child_fn(cp: Component):
         pass
 
+
     def file(self):
         cp = File()
         self._on_before_add_child_fn(cp)
@@ -69,6 +70,15 @@ class BoxContainer(Container):
         self.add_child(cp)
         return cp
 
+    def dataframe(self,styler:pd.DataFrame | pdStyler):
+        if isinstance(styler,pd.DataFrame):
+            styler = styler.style
+
+        cp = Dataframe(styler)
+        self._on_before_add_child_fn(cp)
+        self.add_child(cp)
+        return cp
+
     def image_from_url(self,url:str):
         return self.__image(url)
     
@@ -125,8 +135,13 @@ class BoxContainer(Container):
         self.add_child(cp)
         return cp
 
-    def dataTable(self, dataframe: Union[pd.DataFrame,FileData], page_size=5):
-        cp = DataTable(self._on_before_data_fn(dataframe))
+    def dataTable(self, reactDataset: pd.DataFrame | ReactiveDatasetPropInfo | DatasetSeriesPropInfo, page_size=5):
+
+        if isinstance(reactDataset,pd.DataFrame):
+            reactDataset = self._on_before_data_fn(reactDataset)
+
+
+        cp = DataTable(reactDataset)
         cp.page_size = page_size
         self._on_before_add_child_fn(cp)
         self.add_child(cp)
@@ -143,11 +158,8 @@ class BoxContainer(Container):
 
         return cp
 
-    def plotly(self, data:Optional[pd.DataFrame]=None):
-        info=None
-        if not data is None:
-            info = self._on_before_data_fn(data)
-        cp = Plotly(info)
+    def plotly(self):
+        cp = Plotly()
         self._on_before_add_child_fn(cp)
         self.add_child(cp)
         return cp
@@ -175,22 +187,19 @@ class BoxContainer(Container):
         self.add_child(cp)
         return cp
 
-    def select(self, options: Iterable[str]):
+    def select(self, options: Iterable[str] | DatasetSeriesArrayPropInfo | ReactiveDatasetPropInfo | DatasetSeriesPropInfo):
         cp = Select(options)
         self._on_before_add_child_fn(cp)
         self.add_child(cp)
         return cp
 
-    def echart(self, data:Optional[pd.DataFrame]=None):
-        info=None
-        if not data is None:
-            info = self._on_before_data_fn(data)
-        cp = EChart(info)
+    def echart(self):
+        cp = EChart()
         self._on_before_add_child_fn(cp)
         self.add_child(cp)
         return cp
 
-    def markdown(self, md: str, **prop_mapping: TypePropInfo):
+    def markdown(self, md: str, **prop_mapping: TTypePropInfo):
         layout = MarkdownLayout(md, prop_mapping)
 
         box = self.__markdown_box()
@@ -213,14 +222,13 @@ class BoxContainer(Container):
 
     def _ex_get_react_data(self) -> Dict[str, Any]:
         data = super()._ex_get_react_data()
-        data.update({'spec': self._spec, 'isHover': False})
+        data.update({'spec': self._spec, 'isHover': False,'teleportTarget':self._teleportTarget})
         return data
 
 
 class ColumnsContainer(Container):
     def __init__(
             self,
-            #  appender_stack: List[Callable[[Component], Component]],
             spec: Union[int, List[int]]) -> None:
         super().__init__('columns-container')
 
