@@ -1,5 +1,5 @@
 from pyvisflow.core.components.components import Component
-from pyvisflow.core.props import TypePropInfo
+from pyvisflow.core.props import TTypePropInfo
 from pyvisflow.models.TComponent import TComponentType
 
 
@@ -7,5 +7,5 @@ class MarkdownValue(Component):
     def __init__(self) -> None:
         super().__init__('markdown-value', TComponentType.builtIn)
 
-    def set_value(self, prop: TypePropInfo):
+    def set_value(self, prop: TTypePropInfo):
         self.set_prop('value', prop)
