@@ -1,23 +1,22 @@
 from typing import Any, Dict, Iterable, List, Tuple, Union
-
-from pydantic import BaseModel
 from pyvisflow.core.props import SubscriptableTypePropInfo, StrTypePropInfo, NumberTypePropInfo
-from pyvisflow.core.props.nameProp import NamePropInfo
+from pyvisflow.core.props.absProp import AbsPropInfo
 
 from .auto_create._select import _Select
 
 
-class TSelectOption(BaseModel):
-    label: str
-    value: int
-
 
 class Select(_Select):
     def __init__(self, options: Iterable[str], multiple=False) -> None:
         super().__init__()
-        options = list(options)
 
-        self._options = options
+        self._options=[]
+
+        if isinstance(options,AbsPropInfo):
+            self.set_prop('options',options)
+        else:
+            options = list(options)
+            self._options = options
 
         self.multiple = multiple
 
