@@ -2,34 +2,78 @@ from __future__ import annotations
 
 from abc import abstractmethod
 from typing import Callable, Generic, List, Optional, Set, Tuple, Dict, TYPE_CHECKING, Generator, TypeVar, Union
-from pyvisflow.core.props.nameProp import NamePropInfo
-from pyvisflow.core.props.valueProp import ValuePropInfo
+from pyvisflow.core.props.objectProp import ObjectMethodCallPropInfo, ObjectPropCallPropInfo
+from pyvisflow.core.props.valueProp import ConstantsPropInfo
 
 from pyvisflow.utils.helper import value2code
 
 from .absProp import AbsPropInfo
 from .combineProp import CombinePropInfo
-from .methodProp import MethodPropInfo
-from .indexProp import IndexPropInfo
-from .fnsMethodProp import FnsMethodPropInfo
+from .methodProp import FnsMethodPropInfo, MethodPropInfo, VarPropInfo
 
-if TYPE_CHECKING:
-    from pyvisflow.core.props.propValuator import Valuator
+class ValueTypePropInfo(AbsPropInfo):
+    def __init__(self, value: AbsPropInfo) -> None:
+        super().__init__()
+        self.value=value
 
 
-class TypePropInfo(AbsPropInfo):
-    def __init__(self, parent: AbsPropInfo) -> None:
-        super().__init__(parent.valuator, parent)
+    def _ex_maybe_child(self) -> Generator:
+        yield self.value
 
+    def gen_expr(self) -> str:
+        return self.value.gen_expr()
 
-class StrTypePropInfo(TypePropInfo):
-    def __init__(self, parent: AbsPropInfo) -> None:
-        super().__init__(parent)
+class ObjectGetItemPropInfo(AbsPropInfo):
+
+    def __init__(self,var:str | AbsPropInfo,key:str | int | AbsPropInfo) -> None:
+        super().__init__()
+
+        if isinstance(var,str):
+            var = VarPropInfo(var)
+        self.var=var
+        self.key=key
+
+    def _ex_maybe_child(self) -> Generator:
+        yield self.var
+        yield self.key
 
     def __eq__(self, __o: Union[str, StrTypePropInfo]):
         v = None
         if isinstance(__o, str):
-            v = ValuePropInfo(None, __o)
+            v = ConstantsPropInfo(__o)
+        else:
+            v = __o
+        cb = CombinePropInfo('==', self, v)
+        return BoolTypePropInfo(cb)
+
+    def __ne__(self, __o: Union[str, StrTypePropInfo]):
+        v = None
+        if isinstance(__o, str):
+            v = ConstantsPropInfo(__o)
+        else:
+            v = __o
+        cb = CombinePropInfo('!=', self, v)
+        return BoolTypePropInfo(cb)
+
+
+    def gen_expr(self) -> str:
+        var = AbsPropInfo._try2expr(self.var)
+        key = AbsPropInfo._try2expr(self.key)
+        return f"{var}[{key}]"
+
+class StrTypePropInfo(AbsPropInfo):
+    def __init__(self, value: AbsPropInfo) -> None:
+        super().__init__()
+        self.value=value
+
+
+    def _ex_maybe_child(self) -> Generator:
+        yield self.value
+
+    def __eq__(self, __o: Union[str, StrTypePropInfo]):
+        v = None
+        if isinstance(__o, str):
+            v = ConstantsPropInfo( __o)
         else:
             v = __o
         cb = CombinePropInfo('==', self, v)
@@ -40,17 +84,16 @@ class StrTypePropInfo(TypePropInfo):
         return BoolTypePropInfo(cb)
 
     @staticmethod
-    def __try2PropInfo(value:Union[str, StrTypePropInfo]):
-        if isinstance(value,StrTypePropInfo):
-            return value
+    def __try2PropInfo(value:Union[str, StrTypePropInfo]) -> AbsPropInfo:
+        # assert isinstance(
+        #     value, (str, StrTypePropInfo)
+        # ), f'type is [{type(value)}],it must be str, StrTypePropInfo'
+
         val = None
-        if isinstance(value, str):
-            val = ValuePropInfo(None, value)
+        if isinstance(value,str):
+            val=ConstantsPropInfo(value)
         else:
-            assert isinstance(
-                value, TypePropInfo
-            ), f'other type is [{type(value)}],it must be str, StrTypePropInfo'
-            val = ValuePropInfo.try2PropInfo(value)
+            val= value
 
         return val
 
@@ -67,15 +110,8 @@ class StrTypePropInfo(TypePropInfo):
     def __radd__(self, other: Union[str, StrTypePropInfo]):
         return StrTypePropInfo.__Combine2str('+',other,self)
 
-    # def __int__(self) -> int:
-    #     return self.toNumber()
-
-    # def __float__(self) -> :
-    #     return self.toNumber()
-
     def slice(self, start: int, end: Optional[int] = None):
-        m = MethodPropInfo(self.valuator, self, 'slice', [start, end])
-
+        m = ObjectMethodCallPropInfo(self, 'slice', [start, end])
         res = StrTypePropInfo(m)
         return res
 
@@ -84,17 +120,21 @@ class StrTypePropInfo(TypePropInfo):
         return NumberTypePropInfo(m)
 
     def length(self):
-        m = NamePropInfo(self.valuator, self, 'length')
+        m = ObjectPropCallPropInfo(self.value, 'length')
         res = NumberTypePropInfo(m)
         return res
 
-    def _ex_gen_expr(self):
-        return ''
+    def gen_expr(self) -> str:
+        return self.value.gen_expr()
 
 
-class NumberTypePropInfo(TypePropInfo):
-    def __init__(self, parent: AbsPropInfo) -> None:
-        super().__init__(parent)
+class NumberTypePropInfo(AbsPropInfo):
+    def __init__(self, value: AbsPropInfo) -> None:
+        super().__init__()
+        self.value=value
+
+    def _ex_maybe_child(self) -> Generator:
+        yield self.value
 
     def __eq__(self, other: Union[float, int, NumberTypePropInfo]):
         return self.__combine4comp('==', other)
@@ -118,12 +158,9 @@ class NumberTypePropInfo(TypePropInfo):
                   other: Union[float, int, NumberTypePropInfo]):
         val = None
         if isinstance(other, (float, int)):
-            val = ValuePropInfo(None, other)
+            val = ConstantsPropInfo(other)
         else:
-            assert isinstance(
-                other, TypePropInfo
-            ), f'other type is [{type(other)}],it must be float,int'
-            val = ValuePropInfo.try2PropInfo(other)
+            val = other
 
         return CombinePropInfo(logic, self, val)
 
@@ -163,23 +200,28 @@ class NumberTypePropInfo(TypePropInfo):
 
     def __floordiv__(self, other: Union[float, int, NumberTypePropInfo]):
         oper1 = self.__combine4cal('/', other)
-        m = FnsMethodPropInfo('floor', [oper1], package_var='Math')
+        m = MethodPropInfo('Math.floor', [oper1])
         return m
 
     def __rfloordiv__(self, other: Union[float, int, NumberTypePropInfo]):
         return self // other
 
     def toString(self):
-        m = MethodPropInfo(self.valuator,self,'toString')
+        m = ObjectMethodCallPropInfo(self,'toString')
         return StrTypePropInfo(m)
 
-    def _ex_gen_expr(self):
-        return ''
+    def gen_expr(self) -> str:
+        return self.value.gen_expr()
 
 
-class BoolTypePropInfo(TypePropInfo):
-    def __init__(self, parent: AbsPropInfo) -> None:
-        super().__init__(parent)
+class BoolTypePropInfo(AbsPropInfo):
+    def __init__(self, value: AbsPropInfo) -> None:
+        super().__init__()
+        self.value=value
+
+
+    def _ex_maybe_child(self) -> Generator:
+        yield self.value
 
     def __and__(self, other: BoolTypePropInfo):
         cb = CombinePropInfo('&&', self, other)
@@ -189,26 +231,36 @@ class BoolTypePropInfo(TypePropInfo):
         cb = CombinePropInfo('||', self, other)
         return BoolTypePropInfo(cb)
 
-    def ex_gen_expr(self):
-        return ''
+    def gen_expr(self) -> str:
+        return self.value.gen_expr()
+
+
 
 
 T = TypeVar('T', str, int)
 TItem = TypeVar('TItem', StrTypePropInfo, NumberTypePropInfo)
 
 
-class SubscriptableTypePropInfo(TypePropInfo, Generic[T, TItem]):
-    def __init__(self, parent: AbsPropInfo) -> None:
-        super().__init__(parent)
+class SubscriptableTypePropInfo(AbsPropInfo, Generic[T, TItem]):
+    def __init__(self, value: AbsPropInfo) -> None:
+        super().__init__()
+        self.value=value
+
+
+    def _ex_maybe_child(self) -> Generator:
+        yield self.value
 
     def __getitem__(self, item: Union[T, TItem]) -> TItem:
-        idx = IndexPropInfo(self.valuator, self, item)
+        item = ObjectGetItemPropInfo(self,item)
 
         if hasattr(self, '__orig_class__'):
             if self.__orig_class__.__args__[1] == StrTypePropInfo:
-                return StrTypePropInfo(idx)
+                return StrTypePropInfo(item)
 
             if self.__orig_class__.__args__[1] == NumberTypePropInfo:
-                return NumberTypePropInfo(idx)
+                return NumberTypePropInfo(item)
 
-        return SubscriptableTypePropInfo(idx)
+        return SubscriptableTypePropInfo(item)
+
+    def gen_expr(self) -> str:
+        return self.value.gen_expr()
