@@ -1,86 +1,85 @@
 from __future__ import annotations
 
-from abc import abstractmethod
 from typing import Any, Callable, List, Optional, Set, Tuple, Dict, TYPE_CHECKING, Generator, Union
-from pyvisflow.core.props.methodProp import LambdaMethodPropInfo
-
+from pyvisflow.core.props.methodProp import LambdaPropInfo
 from pyvisflow.utils.helper import value2code
-
 from .absProp import AbsPropInfo
 
-from pyvisflow.core.props.propValuator import ConstantsValuator, LambdaValuator
-import json
 
 
-class ValuePropInfo(AbsPropInfo):
-    def __init__(self, parent: Union[AbsPropInfo, None],
-                 value: Union[float, int, str]) -> None:
-        super().__init__(ConstantsValuator(), parent)
-        self.value = value
+class ConstantsPropInfo(AbsPropInfo):
+    def __init__(self,
+            value:Any) -> None:
+        super().__init__()
+        self.value=value
+
+    def _ex_maybe_child(self) -> Generator:
+        yield self.value
 
     @staticmethod
     def try2PropInfo(value: Any):
         if (value is None) or isinstance(value, (float, str, int)):
-            return ValuePropInfo(None, value)
+            return ConstantsPropInfo( value)
 
         if isinstance(value, Dict):
-            return JsObjectValuePropInfo(None, value)
+            return JsObjectValuePropInfo( value)
         return value
 
-    def _ex_gen_expr(self):
+    def gen_expr(self) -> str:
         return value2code(self.value)
 
 
-class _DictEncoder(json.JSONEncoder):
-    def default(self, o: Any) -> Any:
-        if isinstance(o, AbsPropInfo):
-            m = LambdaMethodPropInfo(o)
-            return m.valuator.cal(m)
-        return super().default(o)
-
 
 class DictValuePropInfo(AbsPropInfo):
-    def __init__(self, parent: Union[AbsPropInfo, None], value: Dict) -> None:
-        super().__init__(ConstantsValuator(), parent)
+    def __init__(self,  value: Dict) -> None:
+        super().__init__()
         self.value = value
 
+    def _ex_maybe_child(self) -> Generator:
+        yield self.value
+
     @staticmethod
     def try2PropInfo(value: Any):
         if isinstance(value, (dict)):
-            return DictValuePropInfo(None, value)
+            return DictValuePropInfo( value)
         return value
 
-    def _ex_gen_expr(self):
+    def gen_expr(self) -> str:
         def to_code(key, value):
             if not isinstance(value, (AbsPropInfo)):
                 value = value2code(value)
             else:
-                m = LambdaMethodPropInfo(value)
-                value = m.valuator.cal(m)
+                m = LambdaPropInfo([],value)
+                value=m.gen_expr()
             return f'[{value2code(key)},{value}]'
 
         pairs = [to_code(key, value) for key, value in self.value.items()]
         return f"[{','.join(pairs)}]"
 
+  
+
 
 class JsObjectValuePropInfo(AbsPropInfo):
-    def __init__(self, parent: Union[AbsPropInfo, None], obj: Dict) -> None:
-        super().__init__(ConstantsValuator(), parent)
+    def __init__(self,  obj: Dict) -> None:
+        super().__init__()
         self.obj = obj
 
+    def _ex_maybe_child(self) -> Generator:
+        yield self.obj
+
     @staticmethod
     def try2PropInfo(value: Any):
         if isinstance(value, (dict)):
-            return DictValuePropInfo(None, value)
+            return DictValuePropInfo( value)
         return value
 
-    def _ex_gen_expr(self):
+    def gen_expr(self) -> str:
         def to_code(key, value):
             if not isinstance(value, (AbsPropInfo)):
                 value = value2code(value)
             else:
-                m = LambdaMethodPropInfo(value)
-                value = m.valuator.cal(m)
+                m = LambdaPropInfo([],value)
+                value=m.gen_expr()
             return f'{value2code(key)}:{value}'
 
         pairs = [to_code(key, value) for key, value in self.obj.items()]
